# Abaqus CAE Display Preferences

Display preferences commands are used to edit the Abaqus/CAE preferences file, `abaqus_2021.gpr`.

## Classes

### CaeGuiPrefs

```{eval-rst}
.. autoclass:: abaqus.AbaqusCAEDisplayPreferences.CaeGuiPrefs.CaeGuiPrefs
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CaeKerPrefs

```{eval-rst}
.. autoclass:: abaqus.AbaqusCAEDisplayPreferences.CaeKerPrefs.CaeKerPrefs
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### caePrefsAccess

```{eval-rst}
.. automodule:: abaqus.AbaqusCAEDisplayPreferences.caePrefsAccess
    :members:
    :special-members: __init__
    :show-inheritance:
```
